@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Quentin Sculo <squentin@free.fr>
+# Copyright (C) 2005-2011 Quentin Sculo <squentin@free.fr>
 #
 # This file is part of Gmusicbrowser.
 # Gmusicbrowser is free software; you can redistribute it and/or modify
@@ -245,6 +245,20 @@ sub Play
 			RG_set_options($rgv,$rgl);
 			push @elems, $rgv,$rgl,$ac,$ar;
 		}
+		if (my $custom=$::Options{gst_custom})
+		{	$custom="( $custom )" if $custom=~m/^\s*\w/ && $custom=~m/!/;	#make a Bin by default instead of a pipeline
+			my $elem= eval { GStreamer::parse_launch($custom) };
+			warn "gstreamer custom pipeline error : $@\n" if $@;
+			if ($elem && $elem->isa('GStreamer::Bin'))
+			{	my $first=my $last=$elem;
+				# will work at least for simple cases #FIXME could be better
+				$first=@{ $first->iterate_sorted }[0]  while $first->isa('GStreamer::Bin');
+				$last =@{  $last->iterate_sorted }[-1] while  $last->isa('GStreamer::Bin');
+				$elem->add_pad( GStreamer::GhostPad->new('sink', $last->get_pad('sink') ));
+				$elem->add_pad( GStreamer::GhostPad->new('src', $first->get_pad('src') ));
+			}
+			push @elems, $elem if $elem;
+		}
 		if (@elems)
 		{	my $sink0=GStreamer::Bin->new('sink0');
 			push @elems,$Sink;
@@ -258,7 +272,8 @@ sub Play
 	}
 
 	if ($visual_window)
-	{	$VSink->set_xwindow_id($visual_window->window->XID);
+	{	$visual_window->realize unless $visual_window->window;
+		if (my $w=$visual_window->window) { $VSink->set_xwindow_id($w->XID); }
 	}
 	warn "playing $file\n";
 	set_file($file);
@@ -317,7 +332,8 @@ sub create_visuals
 {	unless ($VSink)
 	{	$VSink=GStreamer::ElementFactory->make(ximagesink => 'ximagesink');
 		return unless $VSink;
-		$VSink->set_xwindow_id($visual_window->window->XID);
+		$visual_window->realize unless $visual_window->window;
+		if (my $w=$visual_window->window) { $VSink->set_xwindow_id($w->XID); }
 	}
 	$PlayBin->set('video-sink' => $VSink) if $PlayBin;
 	$PlayBin->set('flags' => [qw/audio vis soft-volume/]) if $PlayBin && $playbin2_ok;
@@ -475,15 +491,17 @@ sub RG_PrefBox
 sub AdvancedOptions
 {	my $self=$_[0];
 	my $vbox=Gtk2::VBox->new(::FALSE, 2);
-	my $gapless= ::NewPrefCheckButton(gst_gapless => _"enable gapless (experimental)", cb=>sub { $self->{modif}=1 });
+	my $modif_cb= sub { $self->{modif}=1 };
+	my $gapless= ::NewPrefCheckButton(gst_gapless => _"enable gapless (experimental)", cb=> $modif_cb);
 	$gapless->set_sensitive(0) unless $playbin2_ok;
 	$vbox->pack_start($gapless,::FALSE,::FALSE,2);
 	my $sg1=Gtk2::SizeGroup->new('horizontal');
-	my $sg2=Gtk2::SizeGroup->new('horizontal');
+	my $custom= ::NewPrefEntry(gst_custom => _"Custom pipeline", cb=>$modif_cb, sizeg1 => $sg1, expand => 1, tip => _"Insert this pipeline before the audio sink", history => 'gst_custom_history');
+	$vbox->pack_start($custom,::FALSE,::FALSE,2);
 	for my $s (sort grep $Sinks{$_}{ok} && $Sinks{$_}{option}, keys %Sinks)
 	{	my $label= $Sinks{$s}{name}||$s;
 		for my $opt (sort split / /,$Sinks{$s}{option})
-		{	my $hbox=::NewPrefEntry("gst_${s}_$opt", "$s $opt : ", cb => sub { $self->{modif}=1 }, sizeg1 => $sg1, sizeg2 => $sg2);
+		{	my $hbox=::NewPrefEntry("gst_${s}_$opt", "$s $opt : ", cb => $modif_cb, sizeg1 => $sg1, expand => 1);
 			$vbox->pack_start($hbox,::FALSE,::FALSE,2);
 		}
 	}
