@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2007 Quentin Sculo <squentin@free.fr>
+# Copyright (C) 2005-2010 Quentin Sculo <squentin@free.fr>
 #
 # This file is part of Gmusicbrowser.
 # Gmusicbrowser is free software; you can redistribute it and/or modify
@@ -18,13 +18,12 @@ use POSIX ':sys_wait_h';	#for WNOHANG in waitpid
 my (@cmd_and_args,$file,$ChildPID,$WatchTag,$WatchTag2,$OUTPUTfh,@pidToKill,$Kill9);
 my $CMDfh;
 my (%supported,$mplayer);
+my $SoftVolume;
 
-our @ISA=('Play_amixer'); #use amixer for volume
+$::PlayPacks{Play_mplayer}=1; #register the package
 
 sub init
-{	Play_amixer::init();
-
-	$mplayer=undef;
+{	$mplayer=undef;
 	for my $path (split /:/, $ENV{PATH})
 	{	if (-x $path.::SLASH.'mplayer')
 		 {$mplayer=$path.::SLASH.'mplayer';last;}
@@ -34,29 +33,36 @@ sub init
 	return bless {},__PACKAGE__;
 }
 
-sub Close {}
-
 sub supported_formats
 {	return () unless $mplayer;
 	unless (keys %supported)
 	{for (qx($mplayer -msglevel all=4 -ac help))
 	 {	if	(m/^(?:mad|ffmp3)\W.*working/){$supported{mp3}=undef}
-		elsif	(m/^vorbis.*working/)	{$supported{ogg}=undef}
+		elsif	(m/^vorbis.*working/)	{$supported{oga}=undef}
 		elsif	(m/^musepack.*working/)	{$supported{mpc}=undef}
 		elsif	(m/^ffflac.*working/)	{$supported{flac}=undef}
 		elsif	(m/^ffwavpack.*working/){$supported{wv}=undef}
-		elsif	(m/^ffape\W/)		{$supported{ape}=undef}
-		#elsif	(m/^ffape.*working/){$supported{ape}=undef} #check
+		elsif	(m/^ffape.*working/)	{$supported{ape}=undef}
+		elsif	(m/^faad.*working/)	{$supported{m4a}=undef}
 	 }
 	}
 	return keys %supported;
 }
 
+sub VolInit
+{	# check if support -volume option
+	$SoftVolume= !system($mplayer,qw/-really-quiet -softvol -volume 100/) unless defined $SoftVolume;
+	return undef if $SoftVolume;	#use methods from this package
+	return Play_amixer::init();	#use methods from Play_amixer
+}
+
 sub Play
 {	(undef,$file,my$sec)=@_;
 	&Stop if $ChildPID;
 	#if ($ChildPID) { print $CMDfh "loadfile $file\n"; print $CMDfh "seek $sec 2\n" if $sec; return}
-	@cmd_and_args=($mplayer,qw/-nocache -slave -vo null/);
+	@cmd_and_args=($mplayer,qw/-nocache -slave -vo null -nolirc/);
+	push @cmd_and_args, qw/-softvol -volume/, cubicvolume($::Volume) if $SoftVolume;
+	warn "@cmd_and_args\n" if $::debug;
 	#push @cmd_and_args,$device_option,$device unless $device eq 'default';
 	push @cmd_and_args,split / /,$::Options{mplayeroptions} if $::Options{mplayeroptions};
 	push @cmd_and_args,'-ss',$sec if $sec;
@@ -106,7 +112,7 @@ sub _remotemsg
 	if ($line=~m/^A:\s*(\d+).\d /)
 	{	::UpdateTime( $1 );
 	}
-	else {warn "mplayer:".$line."\n" if $::debug}
+	elsif ($::debug) {warn "mplayer:$_\n" for @line,$line}
 	return 1;
 }
 
@@ -120,7 +126,7 @@ sub Resume
 sub SkipTo
 {	my $sec=$_[1];
 	::setlocale(::LC_NUMERIC, 'C');
-	print $CMDfh "seek $sec 2\n";
+	print $CMDfh "pausing_keep seek $sec 2\n";
 	::setlocale(::LC_NUMERIC, '');
 }
 
@@ -158,12 +164,42 @@ sub error
 
 sub AdvancedOptions
 {	my $vbox=Gtk2::VBox->new(::FALSE, 2);
-	my $hbox0=::NewPrefEntry('mplayeroptions','mplayer options :');
+	my $hbox0=::NewPrefEntry('mplayeroptions',_"mplayer options :");
 	$vbox->pack_start($hbox0,::FALSE,::FALSE,2);
-	my $hbox=Play_amixer->make_option_widget;
-	$vbox->pack_start($hbox,::FALSE,::FALSE,2);
+	VolInit() unless defined $SoftVolume;
+	$vbox->pack_start(Play_amixer::make_option_widget(),::FALSE,::FALSE,2) unless $SoftVolume;
 	return $vbox;
 }
 
+# Volume functions
+sub GetVolume	{$::Volume}
+sub GetMute	{$::Mute}
+sub SetVolume
+{	shift;
+	my $set=shift;
+	if	($set eq 'mute')	{ $::Mute=$::Volume; $::Volume=0; }
+	elsif	($set eq 'unmute')	{ $::Volume=$::Mute; $::Mute=0;   }
+	elsif	($set=~m/^\+(\d+)$/)	{ $::Volume+=$1; }
+	elsif	($set=~m/^-(\d+)$/)	{ $::Volume-=$1; }
+	elsif	($set=~m/(\d+)/)	{ $::Volume =$1; }
+	$::Volume=0   if $::Volume<0;
+	$::Volume=100 if $::Volume>100;
+	my $cubicvol= cubicvolume($::Volume);	#use a cubic volume scale
+	print $CMDfh "volume $cubicvol 1\n" if $ChildPID;
+	::HasChanged('Vol');
+	$::Options{Volume}=$::Volume;
+	$::Options{Volume_mute}=$::Mute;
+}
+
+sub cubicvolume	#convert a linear volume to cubic volume scale
+{	my $vol=$_[0];
+	$vol= 100*($vol/100)**3;
+	# will be sent to mplayer as string, make sure it use a dot as decimal separator
+	::setlocale(::LC_NUMERIC, 'C');
+	$vol="$vol";
+	::setlocale(::LC_NUMERIC, '');
+	return $vol;
+}
+
 #sub sendcmd {print $CMDfh "$_[0]\n";} #DEBUG #Play_mplayer::sendcmd('volume 0')
 1;
