@@ -561,7 +561,7 @@ sub add_selectfile_column
 		$check->signal_connect( toggled => sub { my ($check,$i)=@_; my $self=::find_ancestor($check,__PACKAGE__); my $active=$check->get_active; $self->{pf_widgets}{$_}[$i]->set_sensitive($active) for keys %{ $self->{pf_widgets} } },$i);
 		#$widget->signal_connect(focus_in_event=> \&scroll_to_entry);
 		$table->attach($check,$col,$col+1,$row,$row+1,'fill','shrink',1,1);
-		$check->show_all; warn $check;
+		$check->show_all;
 		push @toggles,$check;
 		$i++;
 	}
@@ -583,7 +583,7 @@ sub autofill_check
 	my $store=$combo->get_model;
 	$store->clear;
 	$store->set( $store->append, 0, ::PangoEsc(_"Auto fill based on filenames ..."));
-	my @files= Songs::Map('barefilename',$self->{IDs});
+	my @files= map ::filename_to_utf8displayname($_), Songs::Map('barefilename',$self->{IDs});
 	autofill_user_formats();
 	for my $ref (@FORMATS_user,@FORMATS)
 	{	my ($format,$re)=@$ref;
