@@ -118,9 +118,9 @@ sub new
 {   my ($class,$file)=@_;
     my $self=bless {}, $class;
 
-    # check that the file exists and is readable
-    unless ( -e $file && -r $file )
-    {	warn "File '$file' does not exist or cannot be read.\n";
+    # check that the file exists
+    unless (-e $file)
+    {	warn "File '$file' does not exist.\n";
 	return undef;
     }
     $self->{filename} = $file;
