@@ -6,9 +6,10 @@
 # published by the Free Software Foundation
 
 =gmbplugin GMMKEYS
-Gnome mmkeys
-Gnome multimedia keys plugin
-Makes gmusicbrowser reacts to the Next/Previous/Play/Stop multimedia keys in gnome.
+name	Gnome mmkeys
+title	Gnome multimedia keys plugin
+desc	Makes gmusicbrowser react to the Next/Previous/Play/Stop multimedia keys in gnome.
+req	perl(Net::DBus, libnet-dbus-perl perl-Net-DBus)
 =cut
 
 package GMB::Plugin::GMMKEYS;
