@@ -78,7 +78,7 @@ my %sites=	# id => [name,url,?post?,function]	if the function return 1 => lyrics
 $::Options{OPT.'Font'} ||= delete $::Options{OPT.'FontSize'};	#for versions <1.1.6
 
 if (my $site=$::Options{OPT.'LyricSite'}) { delete $::Options{OPT.'LyricSite'} unless exists $sites{$site} } #reset selected site if no longer defined
-::SetDefaultOptions(OPT, font => 10, PathFile => "~/.lyrics/%a/%t.lyric", LyricSite => 'lyricsplugin');
+::SetDefaultOptions(OPT, Font => 10, PathFile => "~/.lyrics/%a/%t.lyric", LyricSite => 'lyricsplugin');
 
 
 my $lyricswidget=
@@ -194,6 +194,7 @@ sub prefbox
 sub filename_preview
 {	return '' unless defined $::SongID;
 	my $t=::pathfilefromformat( $::SongID, $::Options{OPT.'PathFile'}, undef,1);
+	$t= ::filename_to_utf8displayname($t) if $t;
 	$t= $t ? ::PangoEsc(_("example : ").$t) : "<i>".::PangoEsc(_"invalid pattern")."</i>";
 	return '<small>'.$t.'</small>';
 }
@@ -202,7 +203,7 @@ sub SetToolbarHide
 {	my ($self,$hide)=@_;
 	$self->{HideToolbar}=$hide;
 	my $toolbar=$self->{toolbar};
-	if ($self->{HideToolbar})	{$toolbar->hide}
+	if ($self->{HideToolbar})	{$toolbar->set_no_show_all(1); $toolbar->hide}
 	else				{$toolbar->set_no_show_all(0); $toolbar->show_all}
 }
 
